.. _example_notebook:

################
Example Notebook
################

The full notebook lives in the repository:
`Example.ipynb <https://github.com/miaohancheng/pysmatch/blob/main/Example.ipynb>`_.

A runnable script version is also available:

.. literalinclude:: ../../Example.py
   :language: python
